==> cscec5b-wzxt-api-3.0.0-20210615.091157-244-sources.jar: com/ejianc/business/wzxt/vo/ProjectConfigureVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目设置表
 *
 * @author generator
 *
 */
public class ProjectConfigureVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目ID
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long mroProjectId; // MRO项目主键
    private String mroProjectSourceId; // MRO项目来源主键
    private String mroProjectName; // MRO项目名称
    private String def1; // 自定义字段
    private String def2; // 自定义字段
    private String def3; // 自定义字段
    private String def4; // 自定义字段
    private String def5; // 自定义字段


    /**
     * 项目ID
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目ID
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * MRO项目主键
     */
    public Long getMroProjectId() {
        return mroProjectId;
    }

    /**
     * MRO项目主键
     */
    public void setMroProjectId(Long mroProjectId) {
        this.mroProjectId = mroProjectId;
    }
    /**
     * MRO项目来源主键
     */
    public String getMroProjectSourceId() {
        return mroProjectSourceId;
    }

    /**
     * MRO项目来源主键
     */
    public void setMroProjectSourceId(String mroProjectSourceId) {
        this.mroProjectSourceId = mroProjectSourceId;
    }
    /**
     * MRO项目名称
     */
    public String getMroProjectName() {
        return mroProjectName;
    }

    /**
     * MRO项目名称
     */
    public void setMroProjectName(String mroProjectName) {
        this.mroProjectName = mroProjectName;
    }
    /**
     * 自定义字段
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 自定义字段
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 自定义字段
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 自定义字段
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 自定义字段
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 自定义字段
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }

}

==> cscec5b-wzxt-api-3.0.0-20210826.055151-340-sources.jar: com/ejianc/business/wzxt/vo/ProjectConfigureVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目设置表
 *
 * @author generator
 *
 */
public class ProjectConfigureVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目ID
    private String projectName; // 项目名称
    private String projectCode;//项目编号
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private Long mroProjectId; // MRO项目主键
    private String mroProjectSourceId; // MRO项目来源主键
    private String mroProjectName; // MRO项目名称
    private String def1; // 自定义字段
    private String def2; // 自定义字段
    private String def3; // 自定义字段
    private String def4; // 自定义字段
    private String def5; // 自定义字段


    /**
     * 项目ID
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目ID
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * MRO项目主键
     */
    public Long getMroProjectId() {
        return mroProjectId;
    }

    /**
     * MRO项目主键
     */
    public void setMroProjectId(Long mroProjectId) {
        this.mroProjectId = mroProjectId;
    }
    /**
     * MRO项目来源主键
     */
    public String getMroProjectSourceId() {
        return mroProjectSourceId;
    }

    /**
     * MRO项目来源主键
     */
    public void setMroProjectSourceId(String mroProjectSourceId) {
        this.mroProjectSourceId = mroProjectSourceId;
    }
    /**
     * MRO项目名称
     */
    public String getMroProjectName() {
        return mroProjectName;
    }

    /**
     * MRO项目名称
     */
    public void setMroProjectName(String mroProjectName) {
        this.mroProjectName = mroProjectName;
    }
    /**
     * 自定义字段
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 自定义字段
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 自定义字段
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 自定义字段
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 自定义字段
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 自定义字段
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }

}
